@@ -24,6 +24,11 @@ class RedCapStream(RESTStream):
     def url_base(self) -> str:
         """Return the API URL root, configurable via tap settings."""
         return self.config["base_url"]
+    
+    @property
+    def timeout(self) -> int:
+        """Return the API timeout interval, configurable via tap settings."""
+        return self.config["api_timeout"]
 
     records_jsonpath = "$[*]"  # Or override `parse_response`.
     next_page_token_jsonpath = "$.next_page"  # Or override `get_next_page_token`.
