@@ -32,6 +32,11 @@ class TapRedCap(Tap):
             th.StringType,
             description="Base URL for RedCap API service"
         ),
+        th.Property(
+            "api_timeout",
+            th.IntegerType,
+            description="Base URL for RedCap API service"
+        ),
         th.Property(
             "action",
             th.StringType,
