@@ -13,11 +13,15 @@ SAMPLE_CONFIG = {
     "format": "json",
     "type": "eav",
     "forms": ["demographics_form"],
+    "events": "",
     "rawOrLabel": "label",
     "rawOrLabelHeaders": "label",
     "exportCheckboxLabel": "true",
     "exportSurveyFields": "true",
-    "returnFormat": "json"
+    "returnFormat": "json",
+    "exportDataAccessGroups": "true",
+    "base_url": "https://redcap.chop.edu/api/",
+    "api_timeout": 1500
     # TODO: Initialize minimal tap config
 }
 
